@@ -14,7 +14,7 @@
 #include <sys/vfs.h>
 #include "defs.h"
 
-int 
+int
 lren (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int maskbase, destbase, srcbase;
@@ -264,7 +264,7 @@ lren (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lcal (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int success = 0;
@@ -376,7 +376,7 @@ lcal (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lech (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int quit = 0;
@@ -417,7 +417,7 @@ lech (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lrem (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int quit = 0;
@@ -439,7 +439,7 @@ lrem (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lcop (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int track = 0;
@@ -798,7 +798,7 @@ lcop (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lpau (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int count = 0;
@@ -821,7 +821,7 @@ lpau (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lpat (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   char *tptr;
@@ -909,7 +909,7 @@ lpat (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lali (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int defnptr;
@@ -980,7 +980,7 @@ lali (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 luna (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   tc++;
@@ -1011,7 +1011,7 @@ luna (int tc, int tk, int *tks, FILE * in, FILE * out)
 
 #ifdef DIAGNOSE
 
-int 
+int
 ldmp (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   tc++;
@@ -1023,7 +1023,7 @@ ldmp (int tc, int tk, int *tks, FILE * in, FILE * out)
 }
 #endif
 
-int 
+int
 lcd (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int mz;
@@ -1158,7 +1158,7 @@ lcd (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lnd (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int nd;
@@ -1190,7 +1190,7 @@ lnd (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lcls (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   doodle = 0;
@@ -1210,7 +1210,7 @@ lcls (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 ldat (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   char day[4];
@@ -1258,14 +1258,7 @@ ldat (int tc, int tk, int *tks, FILE * in, FILE * out)
 	}
 
       fprintf (out, "Current date is ");
-
-      if (tstr->tm_year < 100)
-	fprintf (out, "%s %02d-%02d-19%02d\n", day, (tstr->tm_mon) + 1, tstr->tm_mday, tstr->tm_year);
-
-      else
-	{
-	  fprintf (out, "%s %02d-%02d-20%02d\n", day, (tstr->tm_mon) + 1, tstr->tm_mday, tstr->tm_year);
-	}
+      fprintf (out, "%s %02d-%02d-%04d\n", day, (tstr->tm_mon) + 1, tstr->tm_mday, tstr->tm_year + 1900);
 
     }
   return tc;
@@ -1278,7 +1271,7 @@ ldat (int tc, int tk, int *tks, FILE * in, FILE * out)
    returns -1 if it failed to change dirs   
  */
 
-int 
+int
 cbf (char *ptr)
 {
   int retval = 0;
@@ -1357,7 +1350,7 @@ cbf (char *ptr)
   return retval;
 }
 
-int 
+int
 ldir (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   static m = 12;
@@ -1529,7 +1522,7 @@ ldir (int tc, int tk, int *tks, FILE * in, FILE * out)
 	  if (!statok && !optbrie)
 	    {
 	      fprintf (out, "\n Volume in drive %c is too loud\n", dcw + 'A');
-	      fprintf (out, " Volume Serial Number is %04lX-%04lX\n", sfs.f_type,
+	      fprintf (out, " Volume Serial Number is %04X-%04X\n", sfs.f_type,
 		       sfs.f_namelen);
 	      fprintf (out, " Directory List\n\n");
 	    }
@@ -1593,7 +1586,7 @@ ldir (int tc, int tk, int *tks, FILE * in, FILE * out)
 				fprintf (out, "<DIR>    ");
 			      fprintf (out, " %02d-%02d-%02d  %2d:%02d%c", (ts->tm_mon) + 1,
 				       ts->tm_mday,
-				       ts->tm_year,
+				       ts->tm_year % 100,
 				       (ts->tm_hour) % 12,
 				       ts->tm_min,
 				       ((ts->tm_hour) / 12) * 15 + 'a');
@@ -1636,7 +1629,7 @@ ldir (int tc, int tk, int *tks, FILE * in, FILE * out)
 				  ts = localtime (&fst.st_atime);
 				  fprintf (out, " %02d-%02d-%02d  %2d:%02d%c", (ts->tm_mon) + 1,
 					   ts->tm_mday,
-					   ts->tm_year,
+					   ts->tm_year % 100,
 					   (ts->tm_hour) % 12,
 					   ts->tm_min,
 					   ((ts->tm_hour) / 12) * 15 + 'a');
@@ -1697,9 +1690,9 @@ ldir (int tc, int tk, int *tks, FILE * in, FILE * out)
 		    }
 		  if (!statok)
 		    {
-		      fprintf (out, "                  %10lu bytes free\n", sfs.f_bavail * fst.st_blksize);
+		      fprintf (out, "                  %10u bytes free\n", sfs.f_bavail * sfs.f_bsize);
 		      if (optcomp)
-			fprintf (out, "                  %10ld file nodes free\n", sfs.f_ffree);
+			fprintf (out, "                  %10d file nodes free\n", sfs.f_ffree);
 
 		    }
 		}
@@ -1727,7 +1720,7 @@ ldir (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 ldel (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int count = 0;
@@ -1907,7 +1900,7 @@ ldel (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lexi (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int temp;
@@ -1935,7 +1928,7 @@ lexi (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lmd (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   tc++;
@@ -1980,7 +1973,7 @@ lmd (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lmap (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int newd;
@@ -2063,7 +2056,7 @@ lmap (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lpro (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   tc++;
@@ -2100,7 +2093,7 @@ lpro (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lrd (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   tc++;
@@ -2146,7 +2139,7 @@ lrd (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lset (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   char *tptr;
@@ -2222,7 +2215,7 @@ lset (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 ltim (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   struct tm *tstr;
@@ -2254,7 +2247,7 @@ ltim (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 ltyp (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   char tbuf[CPBUF];		/*for loslike performance ;-) */
@@ -2341,7 +2334,7 @@ ltyp (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lver (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   tc++;
@@ -2358,7 +2351,7 @@ lver (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lvol (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int trive;
@@ -2419,7 +2412,7 @@ lvol (int tc, int tk, int *tks, FILE * in, FILE * out)
   return tc;
 }
 
-int 
+int
 lzap (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
   int newd;
@@ -2452,7 +2445,7 @@ lzap (int tc, int tk, int *tks, FILE * in, FILE * out)
   return 0;
 }
 
-int 
+int
 ltra (int tc, int tk, int *tks, FILE * in, FILE * out)
 {
 
