@@ -16,7 +16,7 @@
 
 /* print the prompt */
 
-int 
+int
 printprompt (int drive, char *promtstr, FILE * stream)
 {
   int j, i, esc;
@@ -138,12 +138,7 @@ printprompt (int drive, char *promtstr, FILE * stream)
 		  strcpy (day, "Sat");
 		  break;
 		}
-	      if (tstr->tm_year < 100)
-		fprintf (stream, "%s %02d-%02d-19%02d", day, (tstr->tm_mon) + 1, tstr->tm_mday, tstr->tm_year);
-	      else
-		{
-		  fprintf (stream, "%s %02d-%02d-20%02d", day, (tstr->tm_mon) + 1, tstr->tm_mday, tstr->tm_year);
-		}
+	      fprintf (stream, "%s %02d-%02d-%04d", day, (tstr->tm_mon) + 1, tstr->tm_mday, tstr->tm_year + 1900);
 	      break;
 	    case 'P':
 	    case 'p':
